/*
 * XdccDownloader - Nick.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc;

/**
 * Container for a nickname and a prefix. The prefix is a character specific to
 * an IRC server that denotes some kind of special status of a nickname in a
 * channel. The most commonly known prefixes are “@” (for operators) and “+”
 * (for voiced clients) but newer IRCds know other prefixes, such as “!” and
 * “%”, too.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class Nickname {

	/** The name. */
	private final String name;

	/** The prefix. */
	private final String prefix;

	/**
	 * Creates a new nickname.
	 *
	 * @param name
	 * 		The name of the nickname
	 * @param prefix
	 * 		The prefix of the nickname
	 */
	public Nickname(String name, String prefix) {
		this.name = name;
		this.prefix = prefix;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the name of the nickname.
	 *
	 * @return The name of the nickname
	 */
	public String name() {
		return name;
	}

	/**
	 * Returns the prefix of the nickname.
	 *
	 * @return The prefix of the nickname (or an empty string if this nickname does
	 *         not have a prefix)
	 */
	public String prefix() {
		return prefix;
	}

	//
	// OBJECT METHODS
	//

	@Override
	public String toString() {
		return prefix + name;
	}

}
