/*
 * XdccDownloader - ChannelNotJoined.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc.event;

import net.pterodactylus.irc.Connection;

/**
 * Notifies a listener that a channel could not be joined.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class ChannelNotJoined extends AbstractChannelEvent {

	/** The possible reasons for the failure to join a channel. */
	public enum Reason {

		channelIsFull,
		inviteOnly,
		banned,
		badChannelKey,
		badChannelMask,
		noSuchChannel,
		tooManyChannels,
		tooManyTargets,
		unavailable

	}

	/** The reason for the join failure. */
	private final Reason reason;

	/**
	 * Creates a new channel not joined event.
	 *
	 * @param connection
	 * 		The connection this event occured on
	 * @param channel
	 * 		The channel that could not be joined
	 * @param reason
	 * 		The reason for the failure to join the channel
	 */
	public ChannelNotJoined(Connection connection, String channel, Reason reason) {
		super(connection, channel);
		this.reason = reason;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the reason for the failure to join the channel.
	 *
	 * @return The reason for the failure to join the channel
	 */
	public Reason reason() {
		return reason;
	}

}
