/*
 * XdccDownloader - Channel.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.xdcc.data;

import com.google.common.base.Function;

/**
 * Defines a channel in a {@link Network}.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class Channel {

	/** Function to convert a channel to its network. */
	public static final Function<Channel, Network> TO_NETWORK = new Function<Channel, Network>() {
		@Override
		public Network apply(Channel channel) {
			return channel.network();
		}
	};

	/** The network this channel belongs to. */
	private final Network network;

	/** The name of the channel. */
	private final String name;

	/**
	 * Creates a new channel.
	 *
	 * @param network
	 * 		The network the channel belongs to
	 * @param name
	 * 		The name of the channel
	 */
	public Channel(Network network, String name) {
		this.network = network;
		this.name = name;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the network this channel belongs to
	 *
	 * @return The network this channel belongs to
	 */
	public Network network() {
		return network;
	}

	/**
	 * Returns the name of this channel.
	 *
	 * @return The name of this channel
	 */
	public String name() {
		return name;
	}

	//
	// OBJECT METHODS
	//

	@Override
	public boolean equals(Object object) {
		if (!(object instanceof Channel)) {
			return false;
		}
		Channel channel = (Channel) object;
		if (!network().equals(channel.network())) {
			return false;
		}
		if (!name().equalsIgnoreCase(channel.name())) {
			return false;
		}
		return true;
	}

	@Override
	public int hashCode() {
		return network().hashCode() ^ name().hashCode();
	}

}
